@@ -577,6 +577,8 @@ class Archipelagos:
 
                 if file_name.endswith(".csv"):
                     return pd.read_csv(bytes_io)
+                elif file_name.endswith(".parquet"):
+                    return pd.read_parquet(bytes_io)
                 elif file_name.endswith(".json"):
                     return pd.read_json(bytes_io)
                 elif file_name.endswith(".xls") or file_name.endswith(".xlsx"):
