@@ -402,9 +402,7 @@ class TimeSeriesMetadata:
         self._url = metadata.url
         self._summary = metadata.summary
         self._description = metadata.description
-        self._features = metadata.features
         self._frequency = Frequency[metadata.frequency]
-        self._properties = metadata.properties
         self._premium = metadata.premium
 
         self._features = dict()
