@@ -74,8 +74,8 @@ class HttpConstants:
     FORMAT_CSV = "csv"
     TYPE_PARAMETER = "type"
     SOURCE_PARAMETER = "source"
-    CODE_PARAMETER = "code"
-    ID_PARAMETER = "id"
+    CATEGORY_PARAMETER = "category"
+    LABEL_PARAMETER = "label"
     API_KEY_PARAMETER = "api_key"
     START_PARAMETER = "start"
     END_PARAMETER = "end"
